@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-gst.c,v 1.84 2004/06/22 14:16:35 hadess Exp $
+ * $Id: bacon-video-widget-gst.c,v 1.85 2004/07/22 17:59:01 hadess Exp $
  *
  */
 
@@ -1475,14 +1475,14 @@ bacon_video_widget_set_aspect_ratio (BaconVideoWidget *bvw,
   g_return_if_fail (GST_IS_PLAY (bvw->priv->play));
 }
 
-int
+BaconVideoWidgetAspectRatio
 bacon_video_widget_get_aspect_ratio (BaconVideoWidget *bvw)
 {
   g_return_val_if_fail (bvw != NULL, 0);
   g_return_val_if_fail (BACON_IS_VIDEO_WIDGET (bvw), 0);
   g_return_val_if_fail (GST_IS_PLAY (bvw->priv->play), 0);
 
-  return  0;
+  return BVW_RATIO_AUTO;
 }
 
 void
@@ -1902,6 +1902,16 @@ bacon_video_widget_get_popt_table (void)
   return (struct poptOption *) gst_init_get_popt_table ();
 }
 
+GQuark
+bacon_video_widget_error_quark (void)
+{
+  static GQuark q = 0;
+  if (q == 0) {
+    q = g_quark_from_static_string ("bvw-error-quark");
+  }
+  return q;
+}
+
 GtkWidget *
 bacon_video_widget_new (int width, int height,
 			gboolean null_out, GError ** err)
